/*
 * XdccDownloader - MessageReceived.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.core.event;

import net.pterodactylus.irc.Source;

/**
 * Notifies a listener that a message was received.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class MessageReceived {

	/** The source of the message. */
	private final Source source;

	/** The message. */
	private final String message;

	/**
	 * Creates a new message received event.
	 *
	 * @param source
	 * 		The source of the message
	 * @param message
	 * 		The message
	 */
	public MessageReceived(Source source, String message) {
		this.source = source;
		this.message = message;
	}

	//
	// ACCESSORS
	//

	/**
	 * Returns the source of the message.
	 *
	 * @return The source of the message
	 */
	public Source source() {
		return source;
	}

	/**
	 * Returns the message.
	 *
	 * @return The message
	 */
	public String message() {
		return message;
	}

}
