/*
 * XdccDownloader - FailedDownloadsCommand.java - Copyright © 2013 David Roden
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package net.pterodactylus.xdcc.ui.stdin;

import static java.lang.String.format;
import static java.util.Collections.emptySet;

import java.io.IOException;
import java.io.Writer;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;

import net.pterodactylus.xdcc.data.Download;

/**
 * Lists all failed downloads.
 *
 * @author <a href="mailto:bombe@pterodactylus.net">David ‘Bombe’ Roden</a>
 */
public class FailedDownloadsCommand implements Command {

	private final Collection<Download> failedDownloads;

	public FailedDownloadsCommand(Collection<Download> failedDownloads) {
		this.failedDownloads = failedDownloads;
	}

	@Override
	public String getName() {
		return "failed";
	}

	@Override
	public Collection<String> getAliases() {
		return emptySet();
	}

	@Override
	public State execute(State state, List<String> parameters, Writer outputWriter) throws IOException {
		int downloadIndex = 0;
		for (Download download : failedDownloads) {
			outputWriter.write(format("[%d] %s from %s\n", downloadIndex, download.filename(), download.bot().name()));
			downloadIndex++;
		}
		outputWriter.write("End of failed downloads.\n");
		return state.setLastFailedDownloads(new ArrayList<>(failedDownloads));
	}

}
